==> ameba-0.58.tar.bz2: ameba-0.58/processes.cpp <==
#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream>
#include <errlog.h>
#include <astrotime.h>
#include <configs.h>
#include <signal.h>

#include "deftypes.h"
#include "defnames.h"
#include "processes.h"

SV_CMD Observation::cmd = { std::string( program_cfg ), false, false, -1.0 };
bool Observation::terminate = false;
const double alt_to_mean = -5.0*M_PI/180;

Observation::Observation() : acfg( cmd.cfgfile ), Asm( acfg, cmd.man_mode ), objm( acfg, cmd.man_mode ), HR(0), HRE(0)  {
                    // Connection with omicron machine and software components
    serie = acfg.inp<unsigned int>( "General", "Common", "MeasurementSet" );
    exp_serie = acfg.inp<unsigned int>( "General", "Common", "ExperimentSet" );
    if( Asm.start() ) massdimm = std::auto_ptr<Druid>( new Druid( acfg ) );
    check_counter = max_count;
    point_counter = max_point;
    measurement_number = 0;
    stability = false;
}

bool Observation::pointing( const ObjectInfo& target) {
    if( point_counter-- == 0 ) throw ErrFat( ERR_DEV_FUNC, "Pointing failed" );
    if( terminate || !massdimm->point_star( target ) ) return false;
    if( terminate || !massdimm->check_star( target ) ) return false;
    point_counter = max_point;
    return true;
}

// bool Observation::pointing_exper( const ObjectInfo& target) {
//     if( point_counter-- == 0 ) throw ErrFat( ERR_DEV_FUNC, "Pointing failed" );
//     if( terminate || !massdimm->point_star( target ) ) return false;
//     point_counter = max_point;
//     return true;
// }

void Observation::photometry( const std::vector<ObjectInfo>& photometric_list ) {
    for( unsigned int i = 0; i < photometric_list.size(); i++ ) {
        if( ::HR( photometric_list[i] ) == HR ) continue;
        if( pointing( photometric_list[i] ) ) {
            massdimm->measurement();
            massdimm->measurement();
        }
    }
}

void Observation::programm() {
    massdimm->camera( "high" );
    massdimm->mass_usage( true );
    if( objm.get_current( target ) != HR ) {        // Now star will be changed
        if( stability && HR != 0 && objm.get_connected( photometric_list ) != 0 ) photometry( photometric_list );
        if( !pointing( target ) ) {
            HR = objm.get_next( target );
            return;
        }
        HR = ::HR( target );
        check_counter = max_count;
    }
    if( terminate ) return;
    ErrlogSingl::instance().write( "Start measurements run" );
    massdimm->beginning();
    for( unsigned int i = 0; i < serie && !terminate && massdimm->measurement(); i++ ) measurement_number++;
    stability = massdimm->photo_stability();
    if( !terminate && !massdimm->check_status( target ) ) {
        if( check_counter-- == 0 ) throw ErrFat( ERR_DEV_FUNC, "Program measurement failed" );
        objm.get_next( target );
    }
}

void Observation::experiment() {
    massdimm->camera( ( objm.sun_altitude() > alt_to_mean )? "low" : "medium" );
    massdimm->mass_usage( ( objm.sun_altitude() > alt_to_mean )? false : true );
    if( objm.get_current_exper( target ) != HRE ) {
        if( !pointing( target ) ) {
            HRE = objm.get_next_exper( target );
            return;
        }
        HRE = ::HR( target );
        check_counter = max_count;
    }
    if( terminate ) return;
    ErrlogSingl::instance().write( "Start experimental run" );
    massdimm->beginning();
    if( objm.sun_altitude() > alt_to_mean ) {
        massdimm->mass_off();
        for( unsigned int i = 0; i < exp_serie && !terminate; i++ ) massdimm->dimm_measurement();
    } else {
        for( unsigned int i = 0; i < exp_serie && !terminate ; i++ ) massdimm->measurement();
        massdimm->no_check_status( target );
    }
}

==> ameba-0.59.tar.bz2: ameba-0.59/processes.cpp <==
#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream>
#include <errlog.h>
#include <astrotime.h>
#include <configs.h>
#include <signal.h>

#include "deftypes.h"
#include "defnames.h"
#include "processes.h"

SV_CMD Observation::cmd = { std::string( program_cfg ), false, false, -1.0 };
bool Observation::terminate = false;
const double alt_to_mean = -5.0*M_PI/180;

Observation::Observation() : acfg( cmd.cfgfile ), Asm( acfg, cmd.man_mode ), objm( acfg, cmd.man_mode ), HR(0), HRE(0)  {
                    // Connection with omicron machine and software components
    serie = acfg.inp<unsigned int>( "General", "Common", "MeasurementSet" );
    exp_serie = acfg.inp<unsigned int>( "General", "Common", "ExperimentSet" );
    if( Asm.start() ) massdimm = std::auto_ptr<Druid>( new Druid( acfg ) );
    check_counter = max_count;
    point_counter = max_point;
    measurement_number = 0;
    stability = false;
}

bool Observation::pointing( const ObjectInfo& target) {
    if( point_counter-- == 0 ) throw ErrFat( ERR_DEV_FUNC, "Pointing failed" );
    if( terminate || !massdimm->point_star( target ) ) return false;
    if( terminate || !massdimm->check_star( target ) ) return false;
    point_counter = max_point;
    return true;
}

// bool Observation::pointing_exper( const ObjectInfo& target) {
//     if( point_counter-- == 0 ) throw ErrFat( ERR_DEV_FUNC, "Pointing failed" );
//     if( terminate || !massdimm->point_star( target ) ) return false;
//     point_counter = max_point;
//     return true;
// }

void Observation::photometry( const std::vector<ObjectInfo>& photometric_list ) {
    for( unsigned int i = 0; i < photometric_list.size(); i++ ) {
        if( ::HR( photometric_list[i] ) == HR ) continue;
        if( pointing( photometric_list[i] ) ) {
            massdimm->measurement();
            massdimm->measurement();
        }
    }
}

void Observation::programm() {
    massdimm->regime( "normal" );
//    massdimm->mass_usage( true );
    if( objm.get_current( target ) != HR ) {        // Now star will be changed
        if( stability && HR != 0 && objm.get_connected( photometric_list ) != 0 ) photometry( photometric_list );
        if( !pointing( target ) ) {
            HR = objm.get_next( target );
            return;
        }
        HR = ::HR( target );
        check_counter = max_count;
    }
    if( terminate ) return;
    ErrlogSingl::instance().write( "Start measurements run" );
    massdimm->beginning();
    for( unsigned int i = 0; i < serie && !terminate && massdimm->measurement(); i++ ) measurement_number++;
    stability = massdimm->photo_stability();
    if( !terminate && !massdimm->check_status( target ) ) {
        if( check_counter-- == 0 ) throw ErrFat( ERR_DEV_FUNC, "Program measurement failed" );
        objm.get_next( target );
    }
}

void Observation::experiment() {
    massdimm->regime( ( objm.sun_altitude() > alt_to_mean )? "dimm" : "massdimm"  );
//    massdimm->camera( ( objm.sun_altitude() > alt_to_mean )? "low" : "medium" );
//    massdimm->mass_usage( ( objm.sun_altitude() > alt_to_mean )? false : true );
    if( objm.get_current_exper( target ) != HRE ) {
        if( !pointing( target ) ) {
            HRE = objm.get_next_exper( target );
            return;
        }
        HRE = ::HR( target );
        check_counter = max_count;
    }
    if( terminate ) return;
    ErrlogSingl::instance().write( "Start experimental run" );
    massdimm->beginning();
    if( objm.sun_altitude() > alt_to_mean ) {
//        massdimm->mass_off();
        for( unsigned int i = 0; i < exp_serie && !terminate; i++ ) massdimm->dimm_measurement();
    } else {
        for( unsigned int i = 0; i < exp_serie && !terminate ; i++ ) massdimm->measurement();
        massdimm->no_check_status( target );
    }
}
